#
# spec file for package python-typedload
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           python-typedload
Version:        2.28
Release:        1.2
Summary:        Load and dump data from json-like format into typed data structures
License:        GPL-3.0-only
URL:            https://ltworf.github.io/typedload/
# The Github release archive contains both setup.py and the tests. PyPI lacks tests, Github repo lacks generated setup.py
Source0:        https://github.com/ltworf/typedload/releases/download/%{version}/typedload_%{version}.orig.tar.gz
Source1:        https://github.com/ltworf/typedload/releases/download/%{version}/typedload_%{version}.orig.tar.gz.asc
# https://github.com/ltworf/typedload/raw/master/debian/upstream/signing-key.asc
Source2:        python-typedload.keyring
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module base >= 3.5}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Load and dump data from json-like format into typed data structures

%prep
%setup -q -n typedload

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# tests/__main__.py has a version specific test collection and calls unittest.main()
%python_exec -B -m tests

%files %{python_files}
%{python_sitelib}/typedload
%{python_sitelib}/typedload-%{version}*-info

%changelog
* Thu May  2 2024 Dirk Müller <dmueller@suse.com>
- update to 2.28:
  * Add support for uuid.UUID
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 2.27:
  * Add support for re.Patterns
* Wed Dec 13 2023 Dirk Müller <dmueller@suse.com>
- update to 2.26:
  * Update type hints file
  * Improve performance for loading objects
    (attrs/dataclasses/NamedTuple)
  * Improve performance for loading dictionary keys that are
    basic types
  * Improve performance for loading dataclasses
  * Switch performance tests to test against pydantic2
  * Drop support to Python 3.7 (which has reached EOL)
  * Make is_optional slightly faster
  * Keep track of the index when loading iterables the first time
  * It makes the normal case slightly slower, and gives massive
    performance improvements when exceptions are raised.
  * When loading a string into datetime.date/time/datetime, ISO
    8601 is used
  * When dumping, setting `isodates=True` dumps an ISO 8601
    string instead of a list of ints. The previous behaviour is
    now deprecated.
  * Add support for datetime.timedelta. It is dumped as a float
    representing seconds
  * Deprecate dump handlers without type hints
  * Improve performance for dumping, by carrying type hints
  * Remove `jsons` and `dataclasses-json` from benchmarks.
  * They were too slow to be a useful comparison.
  * Improve loading time for literals
  * Support attrs converter
  * Drop support to Python 3.5 and 3.6
  * Improve performance for dumping
  * Generate pure python wheel
  * Switch to setuptools
  * Since python decided to drop the only installation method
    available within the stdlib
  * Add pyproject.toml
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.19
  * Fix minor bug about exception raising from string constructed types
  * Simplify type checking functions, defining only the one for the current python version
  * Fix type definitions of some private functions for compatibility with cython
  * Improved loading speed for dictionaries
  * Improved loading speed for iterators
  * Improved documentation
  * Improved performance testing code
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.18
  * Fix bug with loading generators that raise exceptions
* Sat Oct 30 2021 Ben Greiner <code@bnavigator.de>
- Specfile for version 2.12
- Required by localslackirc
